@@ -26,11 +26,11 @@ sub import {
     return;
 }
 
-die "Perl lib version (v5.8.3) doesn't match executable version ($])"
+die "Perl lib version (v5.8.4) doesn't match executable version ($])"
     unless $^V;
 
-$^V eq v5.8.3
-    or die "Perl lib version (v5.8.3) doesn't match executable version (" .
+$^V eq v5.8.4
+    or die "Perl lib version (v5.8.4) doesn't match executable version (" .
 	sprintf("v%vd",$^V) . ")";
 
 ##
@@ -42,7 +42,7 @@ $^V eq v5.8.3
 #
 ## Package name      : perl5
 ## Source directory  : .
-## Configuration time: Mon Mar 29 00:38:37 UTC 2004
+## Configuration time: Sun Jun 20 07:25:47 UTC 2004
 ## Configured by     : root
 ## Target system     : linux zaurus 2.4.18-rmk7-pxa3-embedix #1 thu, 6 nov 2003 09:29:23 +0900 armv5tel unknown 
 #
@@ -50,7 +50,7 @@ $^V eq v5.8.3
 #PERL_PATCHLEVEL=
 
 our $summary : unique = <<'!END!';
-Summary of my $package (revision $baserev $version_patchlevel_string) configuration:
+Summary of my $package (revision $revision $version_patchlevel_string) configuration:
   Platform:
     osname=$osname, osvers=$osvers, archname=$archname
     uname='$myuname'
@@ -91,21 +91,21 @@ sub myconfig {
 }
 
 our $Config_SH : unique = <<'!END!';
-archlibexp='/home/perl/lib/5.8.3/armv5tel-linux'
+archlibexp='/home/perl/lib/5.8.4/armv5tel-linux'
 archname='armv5tel-linux'
 cc='cc'
 ccflags='-fno-strict-aliasing -I/usr/local/include'
 cppflags='-fno-strict-aliasing -I/usr/local/include'
 dlsrc='dl_dlopen.xs'
 dynamic_ext='B ByteLoader Cwd Data/Dumper Devel/DProf Devel/PPPort Devel/Peek Digest/MD5 Encode Fcntl File/Glob Filter/Util/Call I18N/Langinfo IO IPC/SysV List/Util MIME/Base64 Opcode POSIX PerlIO/encoding PerlIO/scalar PerlIO/via SDBM_File Socket Storable Sys/Hostname Sys/Syslog Time/HiRes Unicode/Normalize XS/APItest XS/Typemap attrs re threads threads/shared'
-installarchlib='/home/perl/lib/5.8.3/armv5tel-linux'
-installprivlib='/home/perl/lib/5.8.3'
-libpth='/usr/local/lib /lib /usr/lib'
+installarchlib='/home/perl/lib/5.8.4/armv5tel-linux'
+installprivlib='/home/perl/lib/5.8.4'
+libpth='/lib /usr/lib'
 libs='-lnsl -lgdbm -ldl -lm -lcrypt -lutil -lc'
 osname='linux'
 osvers=''
 prefix='/home/perl'
-privlibexp='/home/perl/lib/5.8.3'
+privlibexp='/home/perl/lib/5.8.4'
 sharpbang='#!'
 shsharp='true'
 so='so'
@@ -125,11 +125,11 @@ PERL_API_SUBVERSION='0'
 PERL_API_VERSION='8'
 PERL_CONFIG_SH='true'
 PERL_REVISION='5'
-PERL_SUBVERSION='3'
+PERL_SUBVERSION='4'
 PERL_VERSION='8'
 RCSfile='$RCSfile'
 Revision='$Revision'
-SUBVERSION='3'
+SUBVERSION='4'
 Source=''
 State=''
 _a='.a'
@@ -145,7 +145,7 @@ api_subversion='0'
 api_version='8'
 api_versionstring='5.8.0'
 ar='ar'
-archlib='/home/perl/lib/5.8.3/armv5tel-linux'
+archlib='/home/perl/lib/5.8.4/armv5tel-linux'
 archname64=''
 archobjs=''
 asctime_r_proto='0'
@@ -161,14 +161,14 @@ c=''
 castflags='0'
 cat='cat'
 cccdlflags='-fpic'
-ccdlflags='-rdynamic -Wl,-rpath,/home/perl/lib/5.8.3/armv5tel-linux/CORE'
+ccdlflags='-Wl,-E -Wl,-rpath,/home/perl/lib/5.8.4/armv5tel-linux/CORE'
 ccflags_uselargefiles=''
 ccname='gcc'
 ccsymbols='__APCS_32__=1 __ARM_ARCH_4__=1 __CHAR_UNSIGNED__=1 __GNUC_MINOR__=95 __arm=1 __arm__=1 __arm_elf=1 __arm_elf__=1 __linux=1 __linux__=1 __unix=1 __unix__=1 arm=1 arm_elf=1 cpu=arm machine=arm system=posix system=unix'
 ccversion=''
 cf_by='root'
-cf_email='root@zaurus.local.'
-cf_time='Mon Mar 29 00:38:37 UTC 2004'
+cf_email='root@zaurus.home.dan.co.jp'
+cf_time='Sun Jun 20 07:25:47 UTC 2004'
 charsize='1'
 chgrp=''
 chmod='chmod'
@@ -183,9 +183,9 @@ config_arg3='-Uinstallusrbinperl'
 config_arg4='-Dosname=linux'
 config_arg5='-Uusemymalloc'
 config_arg6='-Duselargefiles'
-config_arg7='-desO'
+config_arg7='-rdes'
 config_argc='7'
-config_args='-Dprefix=/home/perl -Duseshrplib -Uinstallusrbinperl -Dosname=linux -Uusemymalloc -Duselargefiles -desO'
+config_args='-Dprefix=/home/perl -Duseshrplib -Uinstallusrbinperl -Dosname=linux -Uusemymalloc -Duselargefiles -rdes'
 contains='grep'
 cp='cp'
 cpio=''
@@ -639,7 +639,7 @@ fpossize='12'
 fpostype='fpos_t'
 freetype='void'
 from=':'
-full_ar='/mnt/dev_img/bin/ar'
+full_ar='/home/sdk/bin/ar'
 full_csh='csh'
 full_sed='/bin/sed'
 gccansipedantic=''
@@ -788,11 +788,11 @@ installman3dir=''
 installprefix='/home/perl'
 installprefixexp='/home/perl'
 installscript='/home/perl/bin'
-installsitearch='/home/perl/lib/site_perl/5.8.3/armv5tel-linux'
+installsitearch='/home/perl/lib/site_perl/5.8.4/armv5tel-linux'
 installsitebin='/home/perl/bin'
 installsitehtml1dir=''
 installsitehtml3dir=''
-installsitelib='/home/perl/lib/site_perl/5.8.3'
+installsitelib='/home/perl/lib/site_perl/5.8.4'
 installsiteman1dir=''
 installsiteman3dir=''
 installsitescript='/home/perl/bin'
@@ -814,8 +814,8 @@ ivtype='long'
 known_extensions='B ByteLoader Cwd DB_File Data/Dumper Devel/DProf Devel/PPPort Devel/Peek Digest/MD5 Encode Fcntl File/Glob Filter/Util/Call GDBM_File I18N/Langinfo IO IPC/SysV List/Util MIME/Base64 NDBM_File ODBM_File Opcode POSIX PerlIO/encoding PerlIO/scalar PerlIO/via SDBM_File Socket Storable Sys/Hostname Sys/Syslog Thread Time/HiRes Unicode/Normalize XS/APItest XS/Typemap attrs re threads threads/shared'
 ksh=''
 ld='cc'
-lddlflags='-shared -L/usr/local/lib'
-ldflags=' -L/usr/local/lib'
+lddlflags='-shared'
+ldflags=''
 ldflags_uselargefiles=''
 ldlibpthname='LD_LIBRARY_PATH'
 less='less'
@@ -825,7 +825,7 @@ libperl='libperl.so'
 libsdirs=' /lib /usr/lib'
 libsfiles=' libnsl.so.1 libgdbm.so.2 libdl.so.2 libm.so.6 libcrypt.so.1 libutil.so.1 libc.so.6'
 libsfound=' /lib/libnsl.so.1 /usr/lib/libgdbm.so.2 /lib/libdl.so.2 /lib/libm.so.6 /lib/libcrypt.so.1 /lib/libutil.so.1 /lib/libc.so.6'
-libspath=' /usr/local/lib /lib /usr/lib'
+libspath=' /lib /usr/lib'
 libswanted='sfio socket bind inet nsl nm ndbm gdbm dbm db malloc dl dld ld sun m crypt sec util c cposix posix ucb bsd BSD'
 libswanted_uselargefiles=''
 line=''
@@ -866,7 +866,7 @@ more='more'
 multiarch='undef'
 mv=''
 myarchname='armv5tel-linux'
-mydomain='.local.'
+mydomain='.home.dan.co.jp'
 myhostname='zaurus'
 myuname='linux zaurus 2.4.18-rmk7-pxa3-embedix #1 thu, 6 nov 2003 09:29:23 +0900 armv5tel unknown '
 n='-n'
@@ -892,7 +892,7 @@ nvtype='double'
 o_nonblock='O_NONBLOCK'
 obj_ext='.o'
 old_pthread_create_joinable=''
-optimize='-O2'
+optimize='-O'
 orderlib='false'
 otherlibdirs=' '
 package='perl5'
@@ -903,18 +903,17 @@ path_sep=':'
 perl5=''
 perl=''
 perl_patchlevel=''
-perladmin='root@zaurus.local.'
+perladmin='root@zaurus.home.dan.co.jp'
 perllibs='-lnsl -ldl -lm -lcrypt -lutil -lc'
 perlpath='/home/perl/bin/perl'
 pg='pg'
 phostname='hostname'
 pidtype='pid_t'
 plibpth=''
-pm_apiversion='5.005'
 pmake=''
 pr=''
 prefixexp='/home/perl'
-privlib='/home/perl/lib/5.8.3'
+privlib='/home/perl/lib/5.8.4'
 procselfexe=''
 prototype='define'
 ptrsize='4'
@@ -973,17 +972,17 @@ sig_num='0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26
 sig_num_init='0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 6, 17, 29, 31, 0'
 sig_size='68'
 signal_t='void'
-sitearch='/home/perl/lib/site_perl/5.8.3/armv5tel-linux'
-sitearchexp='/home/perl/lib/site_perl/5.8.3/armv5tel-linux'
+sitearch='/home/perl/lib/site_perl/5.8.4/armv5tel-linux'
+sitearchexp='/home/perl/lib/site_perl/5.8.4/armv5tel-linux'
 sitebin='/home/perl/bin'
 sitebinexp='/home/perl/bin'
 sitehtml1dir=''
 sitehtml1direxp=''
 sitehtml3dir=''
 sitehtml3direxp=''
-sitelib='/home/perl/lib/site_perl/5.8.3'
+sitelib='/home/perl/lib/site_perl/5.8.4'
 sitelib_stem='/home/perl/lib/site_perl'
-sitelibexp='/home/perl/lib/site_perl/5.8.3'
+sitelibexp='/home/perl/lib/site_perl/5.8.4'
 siteman1dir=''
 siteman1direxp=''
 siteman3dir=''
@@ -1017,8 +1016,8 @@ stdio_stream_array=''
 strerror_r_proto='0'
 strings='/usr/local/include/string.h'
 submit=''
-subversion='3'
-sysman='/usr/local/man/man1'
+subversion='4'
+sysman='/usr/man/man1'
 tail=''
 tar=''
 targetarch=''
@@ -1058,6 +1057,7 @@ usefaststdio='define'
 useithreads='undef'
 uselargefiles='define'
 uselongdouble='undef'
+usemallocwrap='undef'
 usemorebits='undef'
 usemultiplicity='undef'
 usemymalloc='n'
@@ -1099,13 +1099,12 @@ vendorprefix=''
 vendorprefixexp=''
 vendorscript=''
 vendorscriptexp=''
-version='5.8.3'
-version_patchlevel_string='version 8 subversion 3'
+version='5.8.4'
+version_patchlevel_string='version 8 subversion 4'
 versiononly='undef'
 vi=''
 voidflags='15'
 xlibpth='/usr/lib/386 /lib/386'
-xs_apiversion='5.8.3'
 yacc='yacc'
 yaccflags=''
 zcat=''
@@ -1273,21 +1272,21 @@ my $value = join('', unpack('aaaa', pack('L!', $i)));
 
 
 tie %Config, 'Config', {
-    'archlibexp' => '/home/perl/lib/5.8.3/armv5tel-linux',
+    'archlibexp' => '/home/perl/lib/5.8.4/armv5tel-linux',
     'archname' => 'armv5tel-linux',
     'cc' => 'cc',
     'ccflags' => '-fno-strict-aliasing -I/usr/local/include',
     'cppflags' => '-fno-strict-aliasing -I/usr/local/include',
     'dlsrc' => 'dl_dlopen.xs',
     'dynamic_ext' => 'B ByteLoader Cwd Data/Dumper Devel/DProf Devel/PPPort Devel/Peek Digest/MD5 Encode Fcntl File/Glob Filter/Util/Call I18N/Langinfo IO IPC/SysV List/Util MIME/Base64 Opcode POSIX PerlIO/encoding PerlIO/scalar PerlIO/via SDBM_File Socket Storable Sys/Hostname Sys/Syslog Time/HiRes Unicode/Normalize XS/APItest XS/Typemap attrs re threads threads/shared',
-    'installarchlib' => '/home/perl/lib/5.8.3/armv5tel-linux',
-    'installprivlib' => '/home/perl/lib/5.8.3',
-    'libpth' => '/usr/local/lib /lib /usr/lib',
+    'installarchlib' => '/home/perl/lib/5.8.4/armv5tel-linux',
+    'installprivlib' => '/home/perl/lib/5.8.4',
+    'libpth' => '/lib /usr/lib',
     'libs' => '-lnsl -lgdbm -ldl -lm -lcrypt -lutil -lc',
     'osname' => 'linux',
     'osvers' => '',
     'prefix' => '/home/perl',
-    'privlibexp' => '/home/perl/lib/5.8.3',
+    'privlibexp' => '/home/perl/lib/5.8.4',
     'sharpbang' => '#!',
     'shsharp' => 'true',
     'so' => 'so',
